var NAVTREE =
[
  [ "IMP", "index.html", [
    [ "Modules", null, [
      [ "Module/Namespace List", "namespaces.html", "namespaces" ],
      [ "Module/Namespace Members", "namespacemembers.html", [
        [ "All", "namespacemembers.html", "namespacemembers_dup" ],
        [ "Functions", "namespacemembers_func.html", "namespacemembers_func" ],
        [ "Variables", "namespacemembers_vars.html", null ],
        [ "Typedefs", "namespacemembers_type.html", "namespacemembers_type" ],
        [ "Enumerations", "namespacemembers_enum.html", null ],
        [ "Enumerator", "namespacemembers_eval.html", null ]
      ] ]
    ] ],
    [ "Applications", "applications.html", null ],
    [ "All IMP Applications", "applications.html", "applications" ],
    [ "Argument Index", "argument_index.html", [
      [ "IMP.algebra", "argument_index.html#argument_index_algebra", null ],
      [ "IMP.atom", "argument_index.html#argument_index_atom", null ],
      [ "IMP.base", "argument_index.html#argument_index_base", null ],
      [ "IMP.cnmultifit", "argument_index.html#argument_index_cnmultifit", null ],
      [ "IMP.container", "argument_index.html#argument_index_container", null ],
      [ "IMP.core", "argument_index.html#argument_index_core", null ],
      [ "IMP.display", "argument_index.html#argument_index_display", null ],
      [ "IMP.domino", "argument_index.html#argument_index_domino", null ],
      [ "IMP.em", "argument_index.html#argument_index_em", null ],
      [ "IMP.em2d", "argument_index.html#argument_index_em2d", null ],
      [ "IMP.isd", "argument_index.html#argument_index_isd", null ],
      [ "IMP.kernel", "argument_index.html#argument_index_kernel", null ],
      [ "IMP.kinematics", "argument_index.html#argument_index_kinematics", null ],
      [ "IMP.misc", "argument_index.html#argument_index_misc", null ],
      [ "IMP.modeller", "argument_index.html#argument_index_modeller", null ],
      [ "IMP.multifit", "argument_index.html#argument_index_multifit", null ],
      [ "IMP.rotamer", "argument_index.html#argument_index_rotamer", null ],
      [ "IMP.saxs", "argument_index.html#argument_index_saxs", null ],
      [ "IMP.statistics", "argument_index.html#argument_index_statistics", null ]
    ] ],
    [ "Class Examples", "class_example_index.html", [
      [ "IMP.algebra", "class_example_index.html#class_example_index_algebra", null ],
      [ "IMP.atom", "class_example_index.html#class_example_index_atom", null ],
      [ "IMP.base", "class_example_index.html#class_example_index_base", null ],
      [ "IMP.container", "class_example_index.html#class_example_index_container", null ],
      [ "IMP.core", "class_example_index.html#class_example_index_core", null ],
      [ "IMP.display", "class_example_index.html#class_example_index_display", null ],
      [ "IMP.domino", "class_example_index.html#class_example_index_domino", null ],
      [ "IMP.em", "class_example_index.html#class_example_index_em", null ],
      [ "IMP.em2d", "class_example_index.html#class_example_index_em2d", null ],
      [ "IMP.example", "class_example_index.html#class_example_index_example", null ],
      [ "IMP.gsl", "class_example_index.html#class_example_index_gsl", null ],
      [ "IMP.kernel", "class_example_index.html#class_example_index_kernel", null ],
      [ "IMP.kmeans", "class_example_index.html#class_example_index_kmeans", null ],
      [ "IMP.misc", "class_example_index.html#class_example_index_misc", null ],
      [ "IMP.modeller", "class_example_index.html#class_example_index_modeller", null ],
      [ "IMP.mpi", "class_example_index.html#class_example_index_mpi", null ],
      [ "IMP.parallel", "class_example_index.html#class_example_index_parallel", null ],
      [ "IMP.rmf", "class_example_index.html#class_example_index_rmf", null ],
      [ "IMP.rotamer", "class_example_index.html#class_example_index_rotamer", null ],
      [ "IMP.saxs", "class_example_index.html#class_example_index_saxs", null ],
      [ "IMP.score_functor", "class_example_index.html#class_example_index_score_functor", null ],
      [ "IMP.statistics", "class_example_index.html#class_example_index_statistics", null ],
      [ "IMP.symmetry", "class_example_index.html#class_example_index_symmetry", null ]
    ] ],
    [ "Factory Index", "factory_index.html", [
      [ "IMP.algebra", "factory_index.html#factory_index_algebra", null ],
      [ "IMP.atom", "factory_index.html#factory_index_atom", null ],
      [ "IMP.base", "factory_index.html#factory_index_base", null ],
      [ "IMP.container", "factory_index.html#factory_index_container", null ],
      [ "IMP.core", "factory_index.html#factory_index_core", null ],
      [ "IMP.display", "factory_index.html#factory_index_display", null ],
      [ "IMP.domino", "factory_index.html#factory_index_domino", null ],
      [ "IMP.em", "factory_index.html#factory_index_em", null ],
      [ "IMP.em2d", "factory_index.html#factory_index_em2d", null ],
      [ "IMP.example", "factory_index.html#factory_index_example", null ],
      [ "IMP.isd", "factory_index.html#factory_index_isd", null ],
      [ "IMP.kernel", "factory_index.html#factory_index_kernel", null ],
      [ "IMP.kinematics", "factory_index.html#factory_index_kinematics", null ],
      [ "IMP.misc", "factory_index.html#factory_index_misc", null ],
      [ "IMP.multifit", "factory_index.html#factory_index_multifit", null ],
      [ "IMP.pmi", "factory_index.html#factory_index_pmi", null ],
      [ "IMP.rotamer", "factory_index.html#factory_index_rotamer", null ],
      [ "IMP.saxs", "factory_index.html#factory_index_saxs", null ],
      [ "IMP.statistics", "factory_index.html#factory_index_statistics", null ]
    ] ],
    [ "Function Examples", "function_example_index.html", [
      [ "IMP.algebra", "function_example_index.html#function_example_index_algebra", null ],
      [ "IMP.atom", "function_example_index.html#function_example_index_atom", null ],
      [ "IMP.base", "function_example_index.html#function_example_index_base", null ],
      [ "IMP.core", "function_example_index.html#function_example_index_core", null ],
      [ "IMP.display", "function_example_index.html#function_example_index_display", null ],
      [ "IMP.domino", "function_example_index.html#function_example_index_domino", null ],
      [ "IMP.em", "function_example_index.html#function_example_index_em", null ],
      [ "IMP.em2d", "function_example_index.html#function_example_index_em2d", null ],
      [ "IMP.kernel", "function_example_index.html#function_example_index_kernel", null ],
      [ "IMP.rmf", "function_example_index.html#function_example_index_rmf", null ],
      [ "IMP.saxs", "function_example_index.html#function_example_index_saxs", null ],
      [ "IMP.statistics", "function_example_index.html#function_example_index_statistics", null ]
    ] ],
    [ "Design example", "designexample.html", [
      [ "Original Description", "designexample.html#design_original", [
        [ "Comments on the original description", "designexample.html#design_original_comments", null ]
      ] ],
      [ "Design Proposal for Reading", "designexample.html#design_reading", null ],
      [ "Implementing Scoring as a IMP::Restraint", "designexample.html#design_restraint", null ],
      [ "Implementing Scoring as a IMP::PairScore", "designexample.html#design_score", null ],
      [ "Some final thoughts", "designexample.html#design_final", null ]
    ] ],
    [ "Developer Guide", "devguide.html", [
      [ "Getting around IMP", "devguide.html#devguide_getting_around", null ],
      [ "Writing new code", "devguide.html#devguide_new_code", [
        [ "Coding conventions", "devguide.html#devguide_conventions", [
          [ "Indentation", "devguide.html#devguide_indentation", null ],
          [ "Names", "devguide.html#devguide_names", null ],
          [ "Passing and storing data", "devguide.html#devguide_passing", null ],
          [ "Display", "devguide.html#devguide_display", null ],
          [ "Errors", "devguide.html#devguide_errors", null ],
          [ "Namespaces", "devguide.html#devguide_namespace", null ]
        ] ],
        [ "Documenting your code", "devguide.html#devguide_documenting", null ],
        [ "Debugging and testing your code", "devguide.html#devguide_testing", null ],
        [ "Writing Examples", "devguide.html#devguide_examples", null ],
        [ "Exporting code to Python", "devguide.html#devguide_swig", null ]
      ] ],
      [ "Managing your own module", "devguide.html#devguide_module", null ],
      [ "Contributing code back to the repository", "devguide.html#devguide_contributing", [
        [ "Once you have submitted code", "devguide.html#devguide_supporting", null ],
        [ "Cross platform compatibility", "devguide.html#devguide_cross_platform", [
          [ "C++ 11", "devguide.html#devguide_cxx11", null ]
        ] ]
      ] ],
      [ "Good programming practices", "devguide.html#devguide_cpp", null ],
      [ "IMP gotchas", "devguide.html#devguide_gotchas", null ],
      [ "Further reading", "devguide.html#devguide_further_reading", null ]
    ] ],
    [ "Installation", "installation.html", [
      [ "Prerequisites", "installation.html#installation_prereqs", [
        [ "Getting prerequisites on a Mac", "installation.html#installation_prereqs_mac", null ],
        [ "Getting prerequisites on Windows", "installation.html#installation_prereqs_windows", null ]
      ] ],
      [ "Optional prerequisites", "installation.html#installation_preqs_optional", null ],
      [ "Where to go next", "installation.html#installation_next", null ]
    ] ],
    [ "Introduction", "introduction.html", [
      [ "Integrative modeling", "introduction.html#introduction_intmod", [
        [ "Example modeling efforts", "introduction.html#introduction_efforts", null ],
        [ "The four stage process", "introduction.html#introduction_four_stages", null ]
      ] ],
      [ "IMP", "introduction.html#introduction_imp", [
        [ "Representation: IMP::Model", "introduction.html#introduction_representation", null ],
        [ "Decorators", "introduction.html#introduction_decorators", null ],
        [ "Representing biological molecules", "introduction.html#introduction_biomolecules", null ],
        [ "Containers", "introduction.html#introduction_containers", null ],
        [ "Constraints and Invariants", "introduction.html#introduction_constraints", null ],
        [ "Scoring", "introduction.html#introduction_scoring", [
          [ "Restraints", "introduction.html#introduction_restraints", null ],
          [ "Scoring functions", "introduction.html#introduction_scoring_functions", null ]
        ] ],
        [ "Sampling", "introduction.html#introduction_sampling", [
          [ "Optimizers", "introduction.html#introduction_optimizers", null ],
          [ "Samplers", "introduction.html#introduction_samplers", null ]
        ] ],
        [ "Storing and analysis", "introduction.html#introduction_analsysis", null ],
        [ "Modular structure of IMP", "introduction.html#introduction_modular", null ],
        [ "Understanding what is going on", "introduction.html#introduction_understanding", [
          [ "Logging", "introduction.html#introduction_logging", null ],
          [ "Runtime checks", "introduction.html#introduction_checks", null ]
        ] ],
        [ "Conventions", "introduction.html#introduction_conventions", [
          [ "Units", "introduction.html#introduction_units", null ],
          [ "Names", "introduction.html#introduction_names", null ],
          [ "Graphs", "introduction.html#introduction_graphs", null ],
          [ "Values and Objects (C++ only)", "introduction.html#introduction_values", null ],
          [ "Backwards compatibility and deprecation", "introduction.html#introduction_backwards", null ]
        ] ]
      ] ],
      [ "Where to go next", "introduction.html#introduction_next", null ]
    ] ],
    [ "Publications", "publications.html", null ],
    [ "ChangeLog", "changelog.html", [
      [ "For IMP 2.3.1", "changelog.html#changelog_2_3_1", null ],
      [ "For IMP 2.3.0", "changelog.html#changelog_2_3_0", null ],
      [ "For IMP 2.2.1", "changelog.html#changelog_2_2_1", null ],
      [ "For IMP 2.2.0", "changelog.html#changelog_2_2_0", null ],
      [ "For IMP 2.1.1", "changelog.html#changelog_2_1_1", null ],
      [ "For IMP 2.1", "changelog.html#changelog_2_1", null ],
      [ "For IMP 2.0", "changelog.html#changelog_2_0", null ]
    ] ],
    [ "Tools", "dev_tools.html", [
      [ "Making a module", "dev_tools.html#dev_tools_make_module", null ],
      [ "Formatting your code", "dev_tools.html#dev_tools_clang_format", null ],
      [ "Checking standards", "dev_tools.html#dev_tools_check_standards", null ]
    ] ],
    [ "Dependencies", "dependencies.html", [
      [ "Dependency graph", "dependencies.html#dependency_graph", null ],
      [ "Caching dependencies", "dependencies.html#dependency_caching", null ]
    ] ],
    [ "PMI changelog", "pmi_changelog.html", null ],
    [ "Deprecated List", "deprecated.html", null ],
    [ "Groups", "modules.html", "modules" ],
    [ "Classes", null, [
      [ "Class List", "annotated.html", "annotated" ],
      [ "Class Index", "classes.html", null ],
      [ "Class Hierarchy", "hierarchy.html", "hierarchy" ],
      [ "Class Members", "functions.html", [
        [ "All", "functions.html", "functions_dup" ],
        [ "Functions", "functions_func.html", "functions_func" ],
        [ "Variables", "functions_vars.html", null ],
        [ "Enumerations", "functions_enum.html", null ],
        [ "Related Functions", "functions_rela.html", null ]
      ] ]
    ] ],
    [ "Files", null, [
      [ "File List", "files.html", "files" ],
      [ "File Members", "globals.html", [
        [ "All", "globals.html", null ],
        [ "Functions", "globals_func.html", null ],
        [ "Macros", "globals_defs.html", null ]
      ] ]
    ] ],
    [ "Examples", "examples.html", "examples" ],
    [ "Indexes", "argument_index.html", [
      [ "Class Usage", "argument_index.html", null ],
      [ "Class Examples", "class_example_index.html", null ],
      [ "Class Factories", "factory_index.html", null ],
      [ "Function Examples", "function_example_index.html", null ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
".html",
"Cosine_8h_source.html",
"FFToperations_8h.html#ade457bcb204e0cdbc3f37c62735a95c3",
"MinimumSingletonRestraint_8h.html",
"Representation_8h.html#a0413486542eba96a7d75081dff43a096",
"SphereD_8h_source.html",
"Writer_8h.html#a144d1cadcee25ee07afe7e531251f09b",
"atom_2edit_molecular_hierarchy_8py-example.html",
"classIMP_1_1algebra_1_1DefaultEmbeddingD.html#aa939cc38c61633c05ba8f512671c9922",
"classIMP_1_1algebra_1_1Rotation3D.html#a245bbd42a3c675e79a9ad216d7b63be4",
"classIMP_1_1atom_1_1BackbonePDBSelector.html#aac44df734c94bf99290149aa244ce0e7",
"classIMP_1_1atom_1_1CHARMMResidueTopologyBase.html#aa4f8390a6d5efc7d3a94689490a32808",
"classIMP_1_1atom_1_1ForceFieldParameters.html#afc93d5738add08b79a76395b1afb861b",
"classIMP_1_1atom_1_1Representation.html#a3086e40c0518364751d0fe8098b07335",
"classIMP_1_1base_1_1ConstVector.html#a99e0230f012aef6125ba659f178f198b",
"classIMP_1_1container_1_1AllBipartitePairContainer.html#ab8f999448973bd717dc19c44b3845278",
"classIMP_1_1container_1_1InContainerSingletonFilter.html#a68fbe4b0e18b81e11a16e8aeb0901e50",
"classIMP_1_1container_1_1QuadsConstraint.html",
"classIMP_1_1core_1_1ChildrenRefiner.html#a742dc731ef07bd773f8db1cdaf714330",
"classIMP_1_1core_1_1ExcludedVolumeRestraint.html#a55cdce4fc454a978c696ea619e0e9c97",
"classIMP_1_1core_1_1MCCGSampler.html#a029af2b037f814322fbac56bf6626085",
"classIMP_1_1core_1_1PairRestraint.html#a30451da5a8a91cc076b8cdd92d59862d",
"classIMP_1_1core_1_1SphereDistancePairScore.html#a6d0f9ad42ae7eabe3a7566cef4b44380",
"classIMP_1_1core_1_1XYZR.html#aa301c5a743c45801291cf6b0e1981331",
"classIMP_1_1display_1_1SphereGeometry.html#ad668c1db1984c6bfc47dcc74394d6dc3",
"classIMP_1_1domino_1_1ListSubsetFilterTable.html#a43f47a195717a826c88ad066c1553656",
"classIMP_1_1domino_1_1XYZStates.html#ad7567641498035edf1e6b34ec1af2994",
"classIMP_1_1em2d_1_1JPGImageReaderWriter.html#a87bc26efc426f5621fb1b703e50289ca",
"classIMP_1_1em2d_1_1RelativePositionMover.html",
"classIMP_1_1em_1_1DensityHeader.html#aceade20863282c4ee23068edfb3571ce",
"classIMP_1_1em_1_1ImageHeader.html#aa258ac2876aec3c4f19ddfc24420c37e",
"classIMP_1_1example_1_1ExampleSubsetFilterTable.html#aadb3bc766069259011cbeb54989a40d8",
"classIMP_1_1isd_1_1GaussianProcessInterpolation.html#a1f7c2c2fdd54fe6cca838691ffc65fe8",
"classIMP_1_1isd_1_1MultivariateFNormalSufficient.html#ac469de1c0617786175c5ad823f2e2011",
"classIMP_1_1isd_1_1vonMisesKappaJeffreysRestraint.html#a69c0b213ef8e9ca483f36243c1bd4826",
"classIMP_1_1kernel_1_1PairPredicate.html#a6f6aeb965bba69c8d9d457c9b7703586",
"classIMP_1_1kernel_1_1ScoringFunction.html#abd305fcab8433f621d5d038daac0fe70",
"classIMP_1_1kinematics_1_1ProteinKinematics.html#a158ecc1761e6b1129cfcce34a7625a03",
"classIMP_1_1multifit_1_1ComplementarityRestraint.html#a27d2804cdd56909b2588535dbd00f095",
"classIMP_1_1multifit_1_1GeometricHash.html#acb372a29b472a63cd4cba9d3acba9236",
"classIMP_1_1pmi_1_1CompositeRestraint.html#ad71807d411a54d7a350e1ab62e647c2e",
"classIMP_1_1saxs_1_1Profile.html#a13a4a73f29bf1da5ed7116eaf22df287",
"classIMP_1_1statistics_1_1ConfigurationSetXYZEmbedding.html#a65a5b49353be80013bbe86b5b52d952c",
"core_2ConjugateGradients_8h_source.html",
"doxygen__macros_8h_source.html",
"factory_index.html#factory_index_isd",
"hierarchical__clustering_8h.html#a38a0a5277fb9783dee2f808a24789e88",
"kernel_2ScoreAccumulator_8h.html#a97dfb0f2aa739b208ffc57bb9b30b61e",
"kernel_2doxygen_8h.html#ac49c17678e392533e2f6c5927f6eddab",
"multifit_2RadiusOfGyrationRestraint_8h.html",
"pair__predicates_8h_source.html",
"saxs_8h_source.html",
"structIMP_1_1em_1_1SpiderHeader.html#adcbf89c89216812b3bf0513b37a34724",
"vonMisesKappaConjugateRestraint_8h_source.html"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';
var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';
var navTreeSubIndices = new Array();

function getData(varName)
{
  var i = varName.lastIndexOf('/');
  var n = i>=0 ? varName.substring(i+1) : varName;
  return eval(n.replace(/\-/g,'_'));
}

function stripPath(uri)
{
  return uri.substring(uri.lastIndexOf('/')+1);
}

function stripPath2(uri)
{
  var i = uri.lastIndexOf('/');
  var s = uri.substring(i+1);
  var m = uri.substring(0,i+1).match(/\/d\w\/d\w\w\/$/);
  return m ? uri.substring(i-6) : s;
}

function localStorageSupported()
{
  try {
    return 'localStorage' in window && window['localStorage'] !== null && window.localStorage.getItem;
  }
  catch(e) {
    return false;
  }
}


function storeLink(link)
{
  if (!$("#nav-sync").hasClass('sync') && localStorageSupported()) {
      window.localStorage.setItem('navpath',link);
  }
}

function deleteLink()
{
  if (localStorageSupported()) {
    window.localStorage.setItem('navpath','');
  } 
}

function cachedLink()
{
  if (localStorageSupported()) {
    return window.localStorage.getItem('navpath');
  } else {
    return '';
  }
}

function getScript(scriptName,func,show)
{
  var head = document.getElementsByTagName("head")[0]; 
  var script = document.createElement('script');
  script.id = scriptName;
  script.type = 'text/javascript';
  script.onload = func; 
  script.src = scriptName+'.js'; 
  if ($.browser.msie && $.browser.version<=8) { 
    // script.onload does not work with older versions of IE
    script.onreadystatechange = function() {
      if (script.readyState=='complete' || script.readyState=='loaded') { 
        func(); if (show) showRoot(); 
      }
    }
  }
  head.appendChild(script); 
}

function createIndent(o,domNode,node,level)
{
  var level=-1;
  var n = node;
  while (n.parentNode) { level++; n=n.parentNode; }
  if (node.childrenData) {
    var imgNode = document.createElement("img");
    imgNode.style.paddingLeft=(16*level).toString()+'px';
    imgNode.width  = 16;
    imgNode.height = 22;
    imgNode.border = 0;
    node.plus_img = imgNode;
    node.expandToggle = document.createElement("a");
    node.expandToggle.href = "javascript:void(0)";
    node.expandToggle.onclick = function() {
      if (node.expanded) {
        $(node.getChildrenUL()).slideUp("fast");
        node.plus_img.src = node.relpath+"ftv2pnode.png";
        node.expanded = false;
      } else {
        expandNode(o, node, false, false);
      }
    }
    node.expandToggle.appendChild(imgNode);
    domNode.appendChild(node.expandToggle);
    imgNode.src = node.relpath+"ftv2pnode.png";
  } else {
    var span = document.createElement("span");
    span.style.display = 'inline-block';
    span.style.width   = 16*(level+1)+'px';
    span.style.height  = '22px';
    span.innerHTML = '&#160;';
    domNode.appendChild(span);
  } 
}

var animationInProgress = false;

function gotoAnchor(anchor,aname,updateLocation)
{
  var pos, docContent = $('#doc-content');
  if (anchor.parent().attr('class')=='memItemLeft' ||
      anchor.parent().attr('class')=='fieldtype' ||
      anchor.parent().is(':header')) 
  {
    pos = anchor.parent().position().top;
  } else if (anchor.position()) {
    pos = anchor.position().top;
  }
  if (pos) {
    var dist = Math.abs(Math.min(
               pos-docContent.offset().top,
               docContent[0].scrollHeight-
               docContent.height()-docContent.scrollTop()));
    animationInProgress=true;
    docContent.animate({
      scrollTop: pos + docContent.scrollTop() - docContent.offset().top
    },Math.max(50,Math.min(500,dist)),function(){
      if (updateLocation) window.location.href=aname;
      animationInProgress=false;
    });
  }
}

function newNode(o, po, text, link, childrenData, lastNode)
{
  var node = new Object();
  node.children = Array();
  node.childrenData = childrenData;
  node.depth = po.depth + 1;
  node.relpath = po.relpath;
  node.isLast = lastNode;

  node.li = document.createElement("li");
  po.getChildrenUL().appendChild(node.li);
  node.parentNode = po;

  node.itemDiv = document.createElement("div");
  node.itemDiv.className = "item";

  node.labelSpan = document.createElement("span");
  node.labelSpan.className = "label";

  createIndent(o,node.itemDiv,node,0);
  node.itemDiv.appendChild(node.labelSpan);
  node.li.appendChild(node.itemDiv);

  var a = document.createElement("a");
  node.labelSpan.appendChild(a);
  node.label = document.createTextNode(text);
  node.expanded = false;
  a.appendChild(node.label);
  if (link) {
    var url;
    if (link.substring(0,1)=='^') {
      url = link.substring(1);
      link = url;
    } else {
      url = node.relpath+link;
    }
    a.className = stripPath(link.replace('#',':'));
    if (link.indexOf('#')!=-1) {
      var aname = '#'+link.split('#')[1];
      var srcPage = stripPath($(location).attr('pathname'));
      var targetPage = stripPath(link.split('#')[0]);
      a.href = srcPage!=targetPage ? url : "javascript:void(0)"; 
      a.onclick = function(){
        storeLink(link);
        if (!$(a).parent().parent().hasClass('selected'))
        {
          $('.item').removeClass('selected');
          $('.item').removeAttr('id');
          $(a).parent().parent().addClass('selected');
          $(a).parent().parent().attr('id','selected');
        }
        var anchor = $(aname);
        gotoAnchor(anchor,aname,true);
      };
    } else {
      a.href = url;
      a.onclick = function() { storeLink(link); }
    }
  } else {
    if (childrenData != null) 
    {
      a.className = "nolink";
      a.href = "javascript:void(0)";
      a.onclick = node.expandToggle.onclick;
    }
  }

  node.childrenUL = null;
  node.getChildrenUL = function() {
    if (!node.childrenUL) {
      node.childrenUL = document.createElement("ul");
      node.childrenUL.className = "children_ul";
      node.childrenUL.style.display = "none";
      node.li.appendChild(node.childrenUL);
    }
    return node.childrenUL;
  };

  return node;
}

function showRoot()
{
  var headerHeight = $("#top").height();
  var footerHeight = $("#nav-path").height();
  var windowHeight = $(window).height() - headerHeight - footerHeight;
  (function (){ // retry until we can scroll to the selected item
    try {
      var navtree=$('#nav-tree');
      navtree.scrollTo('#selected',0,{offset:-windowHeight/2});
    } catch (err) {
      setTimeout(arguments.callee, 0);
    }
  })();
}

function expandNode(o, node, imm, showRoot)
{
  if (node.childrenData && !node.expanded) {
    if (typeof(node.childrenData)==='string') {
      var varName    = node.childrenData;
      getScript(node.relpath+varName,function(){
        node.childrenData = getData(varName);
        expandNode(o, node, imm, showRoot);
      }, showRoot);
    } else {
      if (!node.childrenVisited) {
        getNode(o, node);
      } if (imm || ($.browser.msie && $.browser.version>8)) { 
        // somehow slideDown jumps to the start of tree for IE9 :-(
        $(node.getChildrenUL()).show();
      } else {
        $(node.getChildrenUL()).slideDown("fast");
      }
      if (node.isLast) {
        node.plus_img.src = node.relpath+"ftv2mlastnode.png";
      } else {
        node.plus_img.src = node.relpath+"ftv2mnode.png";
      }
      node.expanded = true;
    }
  }
}

function glowEffect(n,duration)
{
  n.addClass('glow').delay(duration).queue(function(next){
    $(this).removeClass('glow');next();
  });
}

function highlightAnchor()
{
  var aname = $(location).attr('hash');
  var anchor = $(aname);
  if (anchor.parent().attr('class')=='memItemLeft'){
    var rows = $('.memberdecls tr[class$="'+
               window.location.hash.substring(1)+'"]');
    glowEffect(rows.children(),300); // member without details
  } else if (anchor.parents().slice(2).prop('tagName')=='TR') {
    glowEffect(anchor.parents('div.memitem'),1000); // enum value
  } else if (anchor.parent().attr('class')=='fieldtype'){
    glowEffect(anchor.parent().parent(),1000); // struct field
  } else if (anchor.parent().is(":header")) {
    glowEffect(anchor.parent(),1000); // section header
  } else {
    glowEffect(anchor.next(),1000); // normal member
  }
  gotoAnchor(anchor,aname,false);
}

function selectAndHighlight(hash,n)
{
  var a;
  if (hash) {
    var link=stripPath($(location).attr('pathname'))+':'+hash.substring(1);
    a=$('.item a[class$="'+link+'"]');
  }
  if (a && a.length) {
    a.parent().parent().addClass('selected');
    a.parent().parent().attr('id','selected');
    highlightAnchor();
  } else if (n) {
    $(n.itemDiv).addClass('selected');
    $(n.itemDiv).attr('id','selected');
  }
  if ($('#nav-tree-contents .item:first').hasClass('selected')) {
    $('#nav-sync').css('top','30px');
  } else {
    $('#nav-sync').css('top','5px');
  }
  showRoot();
}

function showNode(o, node, index, hash)
{
  if (node && node.childrenData) {
    if (typeof(node.childrenData)==='string') {
      var varName    = node.childrenData;
      getScript(node.relpath+varName,function(){
        node.childrenData = getData(varName);
        showNode(o,node,index,hash);
      },true);
    } else {
      if (!node.childrenVisited) {
        getNode(o, node);
      }
      $(node.getChildrenUL()).css({'display':'block'});
      if (node.isLast) {
        node.plus_img.src = node.relpath+"ftv2mlastnode.png";
      } else {
        node.plus_img.src = node.relpath+"ftv2mnode.png";
      }
      node.expanded = true;
      var n = node.children[o.breadcrumbs[index]];
      if (index+1<o.breadcrumbs.length) {
        showNode(o,n,index+1,hash);
      } else {
        if (typeof(n.childrenData)==='string') {
          var varName = n.childrenData;
          getScript(n.relpath+varName,function(){
            n.childrenData = getData(varName);
            node.expanded=false;
            showNode(o,node,index,hash); // retry with child node expanded
          },true);
        } else {
          var rootBase = stripPath(o.toroot.replace(/\..+$/, ''));
          if (rootBase=="index" || rootBase=="pages" || rootBase=="search") {
            expandNode(o, n, true, true);
          }
          selectAndHighlight(hash,n);
        }
      }
    }
  } else {
    selectAndHighlight(hash);
  }
}

function removeToInsertLater(element) {
  var parentNode = element.parentNode;
  var nextSibling = element.nextSibling;
  parentNode.removeChild(element);
  return function() {
    if (nextSibling) {
      parentNode.insertBefore(element, nextSibling);
    } else {
      parentNode.appendChild(element);
    }
  };
}

function getNode(o, po)
{
  var insertFunction = removeToInsertLater(po.li);
  po.childrenVisited = true;
  var l = po.childrenData.length-1;
  for (var i in po.childrenData) {
    var nodeData = po.childrenData[i];
    po.children[i] = newNode(o, po, nodeData[0], nodeData[1], nodeData[2],
      i==l);
  }
  insertFunction();
}

function gotoNode(o,subIndex,root,hash,relpath)
{
  var nti = navTreeSubIndices[subIndex][root+hash];
  o.breadcrumbs = $.extend(true, [], nti ? nti : navTreeSubIndices[subIndex][root]);
  if (!o.breadcrumbs && root!=NAVTREE[0][1]) { // fallback: show index
    navTo(o,NAVTREE[0][1],"",relpath);
    $('.item').removeClass('selected');
    $('.item').removeAttr('id');
  }
  if (o.breadcrumbs) {
    o.breadcrumbs.unshift(0); // add 0 for root node
    showNode(o, o.node, 0, hash);
  }
}

function navTo(o,root,hash,relpath)
{
  var link = cachedLink();
  if (link) {
    var parts = link.split('#');
    root = parts[0];
    if (parts.length>1) hash = '#'+parts[1];
    else hash='';
  }
  if (hash.match(/^#l\d+$/)) {
    var anchor=$('a[name='+hash.substring(1)+']');
    glowEffect(anchor.parent(),1000); // line number
    hash=''; // strip line number anchors
    //root=root.replace(/_source\./,'.'); // source link to doc link
  }
  var url=root+hash;
  var i=-1;
  while (NAVTREEINDEX[i+1]<=url) i++;
  if (i==-1) { i=0; root=NAVTREE[0][1]; } // fallback: show index
  if (navTreeSubIndices[i]) {
    gotoNode(o,i,root,hash,relpath)
  } else {
    getScript(relpath+'navtreeindex'+i,function(){
      navTreeSubIndices[i] = eval('NAVTREEINDEX'+i);
      if (navTreeSubIndices[i]) {
        gotoNode(o,i,root,hash,relpath);
      }
    },true);
  }
}

function showSyncOff(n,relpath)
{
    n.html('<img src="'+relpath+'sync_off.png" title="'+SYNCOFFMSG+'"/>');
}

function showSyncOn(n,relpath)
{
    n.html('<img src="'+relpath+'sync_on.png" title="'+SYNCONMSG+'"/>');
}

function toggleSyncButton(relpath)
{
  var navSync = $('#nav-sync');
  if (navSync.hasClass('sync')) {
    navSync.removeClass('sync');
    showSyncOff(navSync,relpath);
    storeLink(stripPath2($(location).attr('pathname'))+$(location).attr('hash'));
  } else {
    navSync.addClass('sync');
    showSyncOn(navSync,relpath);
    deleteLink();
  }
}

function initNavTree(toroot,relpath)
{
  var o = new Object();
  o.toroot = toroot;
  o.node = new Object();
  o.node.li = document.getElementById("nav-tree-contents");
  o.node.childrenData = NAVTREE;
  o.node.children = new Array();
  o.node.childrenUL = document.createElement("ul");
  o.node.getChildrenUL = function() { return o.node.childrenUL; };
  o.node.li.appendChild(o.node.childrenUL);
  o.node.depth = 0;
  o.node.relpath = relpath;
  o.node.expanded = false;
  o.node.isLast = true;
  o.node.plus_img = document.createElement("img");
  o.node.plus_img.src = relpath+"ftv2pnode.png";
  o.node.plus_img.width = 16;
  o.node.plus_img.height = 22;

  if (localStorageSupported()) {
    var navSync = $('#nav-sync');
    if (cachedLink()) {
      showSyncOff(navSync,relpath);
      navSync.removeClass('sync');
    } else {
      showSyncOn(navSync,relpath);
    }
    navSync.click(function(){ toggleSyncButton(relpath); });
  }

  $(window).load(function(){
    navTo(o,toroot,window.location.hash,relpath);
    showRoot();
  });

  $(window).bind('hashchange', function(){
     if (window.location.hash && window.location.hash.length>1){
       var a;
       if ($(location).attr('hash')){
         var clslink=stripPath($(location).attr('pathname'))+':'+
                               $(location).attr('hash').substring(1);
         a=$('.item a[class$="'+clslink+'"]');
       }
       if (a==null || !$(a).parent().parent().hasClass('selected')){
         $('.item').removeClass('selected');
         $('.item').removeAttr('id');
       }
       var link=stripPath2($(location).attr('pathname'));
       navTo(o,link,$(location).attr('hash'),relpath);
     } else if (!animationInProgress) {
       $('#doc-content').scrollTop(0);
       $('.item').removeClass('selected');
       $('.item').removeAttr('id');
       navTo(o,toroot,window.location.hash,relpath);
     }
  })
}

